@@ -46,11 +46,7 @@ def generate( **kwargs ):
 
     return Nanoid( **kwargs ).nanoid
 
-def run( *sys_args ):
-
-    id = generate()
-    print (id)
 
 if __name__ == '__main__':
-    
-    run()
+   
+    print ( generate() )
\ No newline at end of file
